@@ -24,28 +24,24 @@ def is_inside_reaper() -> bool:
 from .tools import (
     connect,
     connect_to_default_machine,
-    Host,
-    LOCALHOST,
     dist_api_is_enabled,
     inside_reaper,
     reconnect,
     generate_imgui,
 )
-from . import reascript_api, errors
-from .config import configure_reaper, add_web_interface
+from . import reascript_api, errors, ImGui
+from .config import configure_reaper
 from .core import *
 from .core.reaper import *
 
-__version__ = "0.10.2"
+__version__ = "0.10.101"
 __all__ = [
     "reascript_api",
     "JS",
+    "ImGui",
     "errors",
     # config
     "configure_reaper",
-    "add_web_interface",
-    "Host",
-    "LOCALHOST",
     # core.reapy_object
     "ReapyObject",
     "ReapyObjectList",
@@ -142,7 +138,6 @@ __all__ = [
     'ui',
     'defer',
     'at_exit',
-    'ExtState',
     # tools
     'connect',
     'connect_to_default_machine',
