@@ -2,20 +2,16 @@ from reapy_boost.errors import DisconnectedClientError, DistError
 from reapy_boost.tools import json
 from .socket import Socket
 
-from ipaddress import IPv4Address, ip_address
-
-LOCALHOST = "127.0.0.1"
-
 
 class Client(Socket):
 
-    def __init__(self, port: int, host: IPv4Address = IPv4Address(LOCALHOST)):
+    def __init__(self, port, host="localhost"):
         super().__init__()
         self._connect(port, host)
         self.port, self.host = port, host
 
-    def _connect(self, port: int, host: IPv4Address):
-        super().connect((str(host), port))
+    def _connect(self, port, host):
+        super().connect((host, port))
         self.address = self.recv(timeout=None).decode("ascii")
 
     def _get_result(self):
